# -*- coding: utf-8 -*-
# Generated by Django 1.11.12 on 2019-06-27 14:04
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('certification', '0004_auto_20190524_1020'),
    ]

    operations = [
        migrations.AlterField(
            model_name='certificationgroup',
            name='_type',
            field=models.CharField(choices=[('workshop', 'Workshop'), ('consultantrole-ambassador', 'ConsultantRoleGroupAmbassador'), ('consultantrole-coach', 'ConsultantRoleGroupCoach'), ('consultantrole-trainer', 'ConsultantRoleGroupTrainer'), ('consultantrole-align-trainer', 'ConsultantRoleGroupAlignTrainer')], max_length=100),
        ),
    ]
