# Generated by Django 2.2.1 on 2019-05-24 10:20

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('certification', '0003_auto_20181024_0932'),
    ]

    operations = [
        migrations.AlterField(
            model_name='certificationgroup',
            name='_type',
            field=models.CharField(choices=[('workshop', 'Workshop')], max_length=100),
        ),
    ]
